@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 """
 Пакет, упрощающий генерацию Browser-UI на основе ExtJS
 с помошью python-кода
 """
-
-from views import workspace
