@@ -81,7 +81,7 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
                 hide: null
             },
             {
-                iconCls: '',
+                iconCls: 'x-form-dropdown-trigger',
                 handler: null,
                 hide: null
             },
@@ -135,14 +135,7 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
         }
 
         // Значения по-умолчанию
-        if (this.defaultRecord) {
-            var record = new Ext.data.Record(this.defaultRecord);
-            this.setRecord(record);
-        } else {
-            if (this.defaultValue && this.defaultText) {
-                this.addRecordToStore(this.defaultValue, this.defaultText);
-            }
-        }
+        this.initDefault();
 
         this.validator = this.validateField;
 
@@ -167,6 +160,7 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
              *   this - Сам компонент
              *   id - Значение
              *   text - Текстовое представление значения
+             *   extraData - Словарь с дополнительными данными из выборанного значения
              * Возвр. значения:
              *   true - обработка продолжается
              *   false - отмена обработки
@@ -187,6 +181,19 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
         this.getStore().baseParams = Ext.applyIf({start: 0, limit: this.defaultLimit }, this.getStore().baseParams);
         this.triggerAction = 'all';
     },
+    /**
+     * Установка значений по-умолчанию
+     */
+    initDefault: function () {
+        if (this.defaultRecord) {
+            var record = new Ext.data.Record(this.defaultRecord);
+            this.setRecord(record);
+        } else {
+            if (this.defaultValue && this.defaultText) {
+                this.addRecordToStore(this.defaultValue, this.defaultText);
+            }
+        }
+    },
     // см. TwinTriggerField
     getTrigger: function (index) {
         return this.triggers[index];
@@ -279,13 +286,7 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
         this.baseTriggers[2].hide = this.hideTriggerDictSelect || this.readOnly || this.disabled;
         this.baseTriggers[3].hide = this.hideTriggerDictEdit || this.readOnly || this.disabled;
 
-        var recordValue;
-        try {
-        	recordValue = Ext.decode(this.getValue());
-        } catch (err) {
-        	recordValue = this.getValue();
-        }
-        if (!recordValue) {
+        if (!this.getValue()) {
             this.baseTriggers[0].hide = true;
             this.baseTriggers[3].hide = true;
         }
@@ -508,9 +509,9 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
                         var win = smart_eval(response.responseText);
                         if (win) {
 
-                            win.on('closed_ok', function (id, displayText) {
-                                if (this.fireEvent('afterselect', this, id, displayText)) {
-                                    this.addRecordToStore(id, displayText);
+                            win.on('closed_ok', function (id, displayText, additionalInfo) {
+                                if (this.fireEvent('afterselect', this, id, displayText, additionalInfo)) {
+                                    this.addRecordToStore(id, displayText, additionalInfo);
                                 }
                             }, this);
                             if (mask) {
@@ -649,13 +650,7 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
     showTriggers: function (show) {
 
         if (show) {
-        	var recordValue;
-        	try {
-        		recordValue = Ext.decode(this.getValue());
-        	} catch (err) {
-        		recordValue = this.getValue();
-        	}
-            if (recordValue) {
+            if (this.getValue()) {
                 this.showClearBtn();
                 this.showEditBtn();
             }
