@@ -1,11 +1,9 @@
-#coding: utf-8
-"""
-Created on 15.03.2010
+# coding: utf-8
+from __future__ import absolute_import
 
-@author: prefer
-"""
 from m3_ext.ui.base import ExtUIComponent
-from base import BaseExtContainer
+
+from .base import BaseExtContainer
 
 
 #==============================================================================
@@ -105,7 +103,10 @@ class ExtContextMenuItem(ExtUIComponent):
 
     def render(self, container=None):
         # FIXME: container не используется
-        res = ['text:"%s"' % self.text.replace('"', "&quot;")]
+        res = [
+            'id: "%s"' % self.client_id,
+            'text:"%s"' % self.text.replace('"', '&quot;'),
+        ]
         if self.custom_itemtype:
             res.append('xtype: "%s"' % self.custom_itemtype)
         if self.icon_cls:
