@@ -35,7 +35,7 @@ class BaseExtField(ExtUIComponent):
         # Этот текст будет выводиться, если поле незаполненно
         self.empty_text = None
 
-        # Минимальные длина поля и текст ошибки, если длина не была достигнута
+        # Минимальные длина поля и текст ошибки, если длина была превышена
         self.min_length = self.min_length_text = None
 
         # Максимальные длина поля и текст ошибки, если длина была превышена
@@ -213,6 +213,13 @@ class BaseExtTriggerField(BaseExtField):
         # изменение ширины выпадающего списка
         self.resizable = False
 
+        # механизм с помощью которого компонент будет скрыт
+        # поддерживает:
+        #           visibility(css visibility),
+        #           offsets (отрицательная позиция смещения),
+        #           display(css display)
+        self.hide_mode = 'offsets'
+
     def set_store(self, store):
         self.mode = 'local' if isinstance(store, ExtDataStore) else 'remote'
         self.__store = store
@@ -287,7 +294,7 @@ class BaseExtTriggerField(BaseExtField):
 
         super(BaseExtTriggerField, self).render_base_config()
 
-        for args in (
+        base_args = [
             ('displayField', self.display_field),
             ('valueField', self.value_field),
             ('hiddenName', self.hidden_name),
@@ -306,6 +313,13 @@ class BaseExtTriggerField(BaseExtField):
             ('store', self.t_render_store, self.get_store()),
             ('listWidth', self.list_width, self.list_width),
             ('tpl', self.list_tpl, self.list_tpl),
-            ('resizable', self.resizable, self.resizable),
-        ):
+            ('resizable', self.resizable, self.resizable)
+        ]
+
+        if self.hidden:
+            base_args.append(
+                ('hideMode', self.hide_mode)
+            )
+
+        for args in base_args:
             self._put_config_value(*args)
