@@ -231,17 +231,11 @@ class ExtDictSelectField(BaseExtTriggerField):
         attr_set = set(self.fields)
         attr_set.add(self.value_field)
         attr_set.add(self.display_field)
-        self.set_empty_record_value()
+        self.__record_value = {}
         for attr in attr_set:
             value = getattr(obj, attr, None)
             self.__record_value[attr] = value() if callable(value) else value
 
-    def set_empty_record_value(self):
-        """
-        Установка пустого record_value.
-        """
-        self.__record_value = {}
-
     @property
     def pack(self):
         return self._pack
@@ -581,6 +575,7 @@ class ExtMultiSelectField(ExtDictSelectField):
 
         super(ExtMultiSelectField, self).__init__(*args, **kwargs)
         self.init_component(*args, **kwargs)
+        self.hidden_name = self.client_id
 
     @property
     def value(self):
